pub struct StatusResponse {
pub connection_id: Option<String>,
pub control_host: String,
pub control_port: i32,
pub daemon_url: String,
pub debug_port: i32,
pub debug_port_active: bool,
pub name: String,
pub state: ClientState,
}Expand description
Current client status
JSON schema
{
"description": "Current client status",
"type": "object",
"required": [
"control_host",
"control_port",
"daemon_url",
"debug_port",
"debug_port_active",
"name",
"state"
],
"properties": {
"connection_id": {
"description": "Connection ID assigned by the daemon upon registration.\nNull if not currently registered (state is \"sleeping\").\n",
"type": "string",
"example": "conn_abc123",
"nullable": true
},
"control_host": {
"description": "Host the control plane is bound to",
"type": "string",
"example": "127.0.0.1"
},
"control_port": {
"description": "Actual port the control plane is listening on.\n0 if the control plane has not been started yet.\n",
"type": "integer",
"format": "int32",
"maximum": 65535.0,
"minimum": 0.0,
"example": 8091
},
"daemon_url": {
"description": "URL of the Detrix daemon this client connects to",
"type": "string",
"example": "http://127.0.0.1:8090"
},
"debug_port": {
"description": "Debug adapter port. 0 if debugger has never been started.\nMay be non-zero even when sleeping due to debugger limitations.\n",
"type": "integer",
"format": "int32",
"maximum": 65535.0,
"minimum": 0.0,
"example": 5678
},
"debug_port_active": {
"description": "True if the debug port is actually open and accepting connections.\nThis may be true even when state is \"sleeping\" because some debuggers\n(e.g., debugpy) cannot stop their listener once started.\n",
"type": "boolean",
"example": true
},
"name": {
"description": "Connection name for this client",
"type": "string",
"example": "my-service-12345"
},
"state": {
"$ref": "#/components/schemas/ClientState"
}
},
"example": {
"connection_id": "conn_abc123",
"control_host": "127.0.0.1",
"control_port": 8091,
"daemon_url": "http://127.0.0.1:8090",
"debug_port": 5678,
"debug_port_active": true,
"name": "my-service-12345",
"state": "awake"
}
}Fields
connection_id: Option<String>Connection ID assigned by the daemon upon registration. Null if not currently registered (state is “sleeping”).
control_host: StringHost the control plane is bound to
control_port: i32Actual port the control plane is listening on. 0 if the control plane has not been started yet.
daemon_url: StringURL of the Detrix daemon this client connects to
debug_port: i32Debug adapter port. 0 if debugger has never been started. May be non-zero even when sleeping due to debugger limitations.
debug_port_active: boolTrue if the debug port is actually open and accepting connections. This may be true even when state is “sleeping” because some debuggers (e.g., debugpy) cannot stop their listener once started.
name: StringConnection name for this client
state: ClientStateTrait Implementations
Sourceimpl Clone for StatusResponse
impl Clone for StatusResponse
Sourcefn clone(&self) -> StatusResponse
fn clone(&self) -> StatusResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StatusResponse
impl Debug for StatusResponse
Sourceimpl<'de> Deserialize<'de> for StatusResponse
impl<'de> Deserialize<'de> for StatusResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&StatusResponse> for StatusResponse
impl From<&StatusResponse> for StatusResponse
Sourcefn from(value: &StatusResponse) -> Self
fn from(value: &StatusResponse) -> Self
Converts to this type from the input type.